Crate reqsign_google

Crate reqsign_google 

Google Service Signer

Typed server-side Cloud Storage Credential Access Boundary downscoping is always available. Enable the credential-access-boundary-client-side feature for local client-side token generation.

Structs

ClientSideCredentialAccessBoundaryGranter
Exchanges source credentials for intermediary material and generates Google Credential Access Boundary tokens locally.
Credential
Credential represents Google credentials that may contain both service account and token.
CredentialAccessBoundaryGrant
A typed, bound Google Cloud Storage Credential Access Boundary.
CredentialAccessBoundaryPermissions
Typed Google Cloud Storage roles supported by Credential Access Boundaries.
DefaultCredentialProvider
Default credential provider for Google Cloud Storage (GCS).
DefaultCredentialProviderBuilder
Builder for DefaultCredentialProvider.
EnvCredentialProvider
FileCredentialProvider
FileCredentialProvider loads Google credentials from an explicit credential file path.
RequestSigner
RequestSigner for Google service requests.
ServerSideCredentialAccessBoundaryGranter
Exchanges a Google OAuth access token for a server-issued CAB token.
ServiceAccount
ServiceAccount holds the client email and private key for service account authentication.
StaticCredentialProvider
StaticCredentialProvider loads credentials from a JSON string provided at construction time.
Token
Token represents an OAuth2 access token with expiration.
TokenCredentialProvider
TokenCredentialProvider loads a raw OAuth access token from memory or a file path.
VmMetadataCredentialProvider
VmMetadataCredentialProvider loads tokens from Google Compute Engine VM metadata service.
WellKnownCredentialProvider