pub struct CredentialAccessBoundaryPermissions(/* private fields */);Expand description
Typed Google Cloud Storage roles supported by Credential Access Boundaries.
The CAB schema names the field availablePermissions, but it does not accept
individual storage.objects.* permission names. It accepts IAM role
identifiers prefixed with inRole:. These constants deliberately expose only
the well-known predefined Cloud Storage object roles, preventing callers from
injecting raw role identifiers or binding a grant to a mutable custom role.
Implementations
Sourceimpl CredentialAccessBoundaryPermissions
impl CredentialAccessBoundaryPermissions
Sourcepub const OBJECT_VIEWER: Self
pub const OBJECT_VIEWER: Self
The predefined Storage Object Viewer role.
Sourcepub const OBJECT_CREATOR: Self
pub const OBJECT_CREATOR: Self
The predefined Storage Object Creator role.
Sourcepub const OBJECT_USER: Self
pub const OBJECT_USER: Self
The predefined Storage Object User role.
Sourcepub const OBJECT_ADMIN: Self
pub const OBJECT_ADMIN: Self
The predefined Storage Object Admin role.