pub struct RequestSigner { /* private fields */ }Expand description
RequestSigner for Google service requests.
Implementations
Sourceimpl RequestSigner
impl RequestSigner
Sourcepub fn new(service: impl Into<String>) -> Self
pub fn new(service: impl Into<String>) -> Self
Create a new builder with the specified service.
Sourcepub fn with_scope(self, scope: impl Into<String>) -> Self
pub fn with_scope(self, scope: impl Into<String>) -> Self
Set the OAuth2 scope.
Sourcepub fn with_signer_email(self, signer_email: impl Into<String>) -> Self
pub fn with_signer_email(self, signer_email: impl Into<String>) -> Self
Set the signer service account email used for query signing via IAMCredentials signBlob.
This is required when generating signed URLs without an embedded service account private key (e.g. ADC / WIF / impersonation tokens).
Sourcepub fn with_region(self, region: impl Into<String>) -> Self
pub fn with_region(self, region: impl Into<String>) -> Self
Set the region for the builder.