RequestSigner

Struct RequestSigner 

pub struct RequestSigner { /* private fields */ }
RequestSigner for Google service requests.

Implementations

Source

impl RequestSigner

pub fn new(service: impl Into<String>) -> Self

Create a new builder with the specified service.

pub fn with_scope(self, scope: impl Into<String>) -> Self

Set the OAuth2 scope.

pub fn with_signer_email(self, signer_email: impl Into<String>) -> Self

Set the signer service account email used for query signing via IAMCredentials signBlob.

This is required when generating signed URLs without an embedded service account private key (e.g. ADC / WIF / impersonation tokens).

pub fn with_region(self, region: impl Into<String>) -> Self

Set the region for the builder.